<?php

namespace App\Livewire;

use Livewire\Component;
use App\Models\JobApplication;
use Illuminate\Support\Facades\Http;

class Dashboard extends Component

{

    public $jobs;
    public $keywords;
    public $classification;
    public $location;
    public $results = [];
    public $searchPerformed = false;
    public $selectedCard = null;
    public $cardData = null;
    public $jobApplication;

    public function search() {
        // Check if all inputs are empty
        if (empty($this->keywords) && empty($this->classification) && empty($this->location)) {
            // If all inputs are empty, get all data from the API
            $response = Http::get(config('app.company_api').'/api/jobs');
        } else {
            // Otherwise, perform API request with user inputs
            $response = Http::get(config('app.company_api').'/api/jobs', [
                'keywords' => $this->keywords,
                'classification' => $this->classification,
                'location' => $this->location,
            ]);
        }

        // Process the API response and filter results
        $this->results = $this->filterResults($response->json());
        $this->searchPerformed = true;
        $this->selectedCard = null;
    }


    private function filterResults($results)
    {
        // Implement your filtering logic here based on user inputs
        // You can use array_filter, collection methods, or other techniques
        // Example: filtering based on keywords
        return array_filter($results, function ($result) {
            $hasKeywords = empty($this->keywords) || stripos($result['job_title'], $this->keywords) !== false;
            $hasClassification = empty($this->classification) || stripos($result['category'], $this->classification) !== false;
            $hasLocation = empty($this->location) || stripos($result['location'], $this->location) !== false;

            // Return true only if at least one search parameter has a value and matches
            return $hasKeywords && $hasClassification && $hasLocation;
        });

    }

    public function selectCard($cardId) {
        $this->selectedCard = $cardId;
        $this->loadCardData();
    }

    public function loadCardData() {
        $response = Http::get("http://localhost:8001/api/jobs/$this->selectedCard");
        if ($response->successful()) {
            $this->cardData = $response->json();
        } else {
        // Handle error or set $this->cardData to null
        $this->cardData = null;
        }
        $this->jobApplication = JobApplication::where('job_id', $this->selectedCard)->get()->first();
    }

    public function render()
    {

        // $user_id = auth()->user()->id;

        // $jobs = Jobs::where('user_id', $user_id)->limit(5)->orderBy('created_at', 'desc')->get();
        // dd($jobs);

        $response = Http::get(config('app.company_api').'/api/jobs');
        $jobs = $response->json();
        // dd($jobs);
        $this->jobs = $jobs;

        return view('livewire.dashboard');
    }
}
