<?php

namespace App\Livewire;

use Carbon\Carbon;
use Livewire\Component;
use App\Models\TimeRecord;

class MyJob extends Component
{

    public $application;
    public $job;
    public $timeRecord;
    public $timeIn;
    public $timeOut;
    
    protected $listeners = ['timeRecordUpdated' => 'checkTimeInRecord'];
    
    public function mount($timeRecord) {
        $this->timeRecord = $timeRecord;
        $this->checkTimeInRecord();
    }

    public function time_in()
    {
        $this->timeIn = Carbon::now();
        $this->timeOut = null;
        $this->saveTimeRecord();
          // Update $timeRecord after calling time_in
        $this->checkTimeInRecord();
    }

    public function time_out()
    {
        $this->timeOut = Carbon::now();
        $this->saveTimeRecord();
        $this->checkTimeInRecord(); // Check for the next day
    }

    private function getTimeRecordForToday()
    {
        // Your logic to retrieve the time record for today from the database
        // Example: Replace this with your actual Eloquent query
        return TimeRecord::whereDate('created_at', Carbon::today())->first();
    }

    private function checkTimeInRecord()
    {
        // Check if there is a time in record for the current day
        // $todayRecord = $this->getTimeRecordForToday();
        $this->timeRecord = TimeRecord::where('job_id', $this->job['id'])
        ->where('user_id', auth()->user()->id)
        ->get();

        $todayRecord = $this->getTimeRecordForToday();
        if ($todayRecord) {
            $this->timeIn = $todayRecord->time_in;
            $this->timeOut = $todayRecord->time_out;
        } else {
            $this->timeIn = null;
            $this->timeOut = null;
        }
    }


    private function saveTimeRecord()
    {

        $existingRecord = TimeRecord::where('job_id', $this->job['id'])
        ->where('user_id', auth()->user()->id)
        ->whereNull('time_out')
        ->first();

    if ($existingRecord) {
        // If an existing record without a time_out exists, update it
        $existingRecord->update([
            'time_out' => $this->timeOut,
        ]);
    } else {
        // If no existing record without a time_out exists, create a new record
        TimeRecord::create([
            'user_id' => auth()->user()->id,
            'job_id' => $this->job['id'],   
            'time_in' => $this->timeIn,
            'time_out' => $this->timeOut,
        ]);
    }

    }

    public function render()
    {   
        // dd($this->timeRecord);
        // logger('Rendering Livewire component');
        return view('livewire.my-job');
    }

}
